# Replace Value in Dict on Python

[![MIT License](http://img.shields.io/badge/license-MIT-blue.svg?style=flat)](LICENSE)


This is a small Python package to replace a target value in dict with an expected value.

## Author
[ashnoa](https://twitter.com/ashnoa)

